*******************
Citing *pyDeltaRCM*
*******************

When citing *pyDeltaRCM*, please cite the `JOSS paper <https://doi.org/10.21105/joss.03398>`_:

	Moodie et al., (2021). pyDeltaRCM: a flexible numerical delta model. Journal of Open Source Software, 6(64), 3398, https://doi.org/10.21105/joss.03398

If you use BibTeX, you can add *pyDeltaRCM* to your `.bib` file using the following code:

.. code:: console

	@article{Moodie2021,
	doi = {10.21105/joss.03398},
	url = {https://doi.org/10.21105/joss.03398},
	year = {2021},
	publisher = {The Open Journal},
	volume = {6},
	number = {64},
	pages = {3398},
	author = {Andrew J. Moodie and Jayaram Hariharan and Eric Barefoot and Paola Passalacqua},
	title = {*pyDeltaRCM*: a flexible numerical delta model},
	journal = {Journal of Open Source Software}
	}
